@@ -1,6 +1,6 @@
 ;;; geiser-repl.el --- Geiser's REPL
 
-;; Copyright (C) 2009, 2010, 2011 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010, 2011, 2012 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -19,6 +19,7 @@
 (require 'geiser-eval)
 (require 'geiser-connection)
 (require 'geiser-menu)
+(require 'geiser-image)
 (require 'geiser-custom)
 (require 'geiser-base)
 
@@ -45,8 +46,10 @@ REPL buffer."
   :type 'boolean
   :group 'geiser-repl)
 
-(geiser-custom--defcustom geiser-repl-history-filename (expand-file-name "~/.geiser_history")
+(geiser-custom--defcustom geiser-repl-history-filename
+    (expand-file-name "~/.geiser_history")
   "File where REPL input history is saved, so that it persists between sessions.
+
 This is actually the base name: the concrete Scheme
 implementation name gets appended to it."
   :type 'filename
@@ -113,6 +116,19 @@ If you have a slow system, try to increase this time."
   :type 'integer
   :group 'geiser-repl)
 
+(geiser-custom--defcustom geiser-repl-inline-images-p t
+  "Whether to display inline images in the REPL."
+  :type 'boolean
+  :group 'geiser-repl)
+
+(geiser-custom--defcustom geiser-repl-auto-display-images-p t
+  "Whether to automatically invoke the external viewer to display
+images popping up in the REPL.
+
+See also `geiser-debug-auto-display-images-p'."
+  :type 'boolean
+  :group 'geiser-repl)
+
 (geiser-custom--defface repl-input
   'comint-highlight-input geiser-repl "evaluated input highlighting")
 
@@ -268,7 +284,10 @@ module command as a string")
 
 (defun geiser-repl--output-filter (txt)
   (geiser-con--connection-update-debugging geiser-repl--connection txt)
-  (when (geiser-con--connection-eot-p geiser-repl--connection txt)
+  (geiser-image--replace-images geiser-repl-inline-images-p
+                                geiser-repl-auto-display-images-p)
+  (when (string-match-p (geiser-con--connection-prompt geiser-repl--connection)
+                        txt)
     (geiser-autodoc--disinhibit-autodoc)))
 
 (defun geiser-repl--start-repl (impl address)
@@ -349,8 +368,8 @@ module command as a string")
 (setq geiser-eval--default-connection-function 'geiser-repl--connection)
 
 (defun geiser-repl--prepare-send ()
-  (geiser-con--connection-deactivate geiser-repl--connection)
-  (geiser-autodoc--inhibit-autodoc))
+  (geiser-autodoc--inhibit-autodoc)
+  (geiser-con--connection-deactivate geiser-repl--connection))
 
 (defun geiser-repl--send (cmd)
   (when (and cmd (eq major-mode 'geiser-repl-mode))
